==> TaltOSv0.1.1.zip: TaltOSv0.1.1/bootloader/lpc2106_init.c <==
/************************************************************************
* This functions are used for initializing LPC2106 chip on an eval board*
************************************************************************/
#include "lpc2106_memorymap.h"
#include "lpc2106_init.h"

void lpc2106_MAM_init(void);

void lpc2106_PLL_init(void);

void lpc2106_ports_init(void);

void lpc2106_serial_init(void);

void lpc2106_timer_init(void);

void lpc2106_MAM_init(void)
{
	REG8(SYSCON_MAMCR) 	= 0x00;		// MAM functions disabled
	REG8(SYSCON_MAMTIM)	= 0x03;		// MAM fech time 1 processor clock
	REG8(SYSCON_MAMCR) 	= 0x02;		// MAM functions fully enabled
}

void lpc2106_PLL_init(void)
{
	REG32(VICIntEnClr) = 0xFFFFFFFF;	// Disabling IT
	// Set up the PLL frequency
	REG8(SYSCON_PLLCFG) = 0x25;		// P = 2, M = 6
	REG8(SYSCON_PLLCON) = 0x01;		// Enabling PLL but not connecting it

	REG8(SYSCON_PLLFEED) = 0xAA;	// Actualising the setting
	REG8(SYSCON_PLLFEED) = 0x55;	// Actualising the setting

	while ( !(REG16(SYSCON_PLLSTAT) & 0x0400) );	// waiting for PLL lock

	REG8(SYSCON_PLLCON) =  0x03;	// Enabling PLL but not connecting it

	REG8(SYSCON_PLLFEED) = 0xAA;	// Actualising the setting
	REG8(SYSCON_PLLFEED) = 0x55;	// Actualising the setting
}

void lpc2106_ports_init(void)
{
	REG32(PCB_PINSEL0) = 0x00000005;	// USART TX / RX
}

void lpc2106_serial_init(void)
{
	REG8(UART0_LCR) = 0x83;		// * bit character 1 stop bit no parity Enable Divisor Latches
	REG8(UART0_DLL) = 98;		// 9600 Baud
	REG8(UART0_DLM) = 0;
	REG8(UART0_LCR) = 0x03;		// * bit character 1 stop bit no parity Disable Divisor Latches
	REG8(UART0_FCR) = 0x01;		// * Enabling and clearing Rx Tx FIFOs
	REG8(UART0_IER) = 0x03;		// Enabling RDA and THRE interrupts for uart0 bit 0 and bit 1
}

void lpc2106_timer_init(void)
{
	REG8(SYSCON_VPBDIV) = 0x00;	// Divide system clock by four for the peripherals 60Mhz/4 = 15Mhz

	REG16(TIMER0_MCR) = 0x3;		// Interrupt and reset on match with MR0
	REG32(TIMER0_PR)  = 100;		// 15Mhz/100 = 0.15Mhz
	REG32(TIMER0_MR0) = 750;		// 0.15Mhz/750 = 200Hz

	REG8(TIMER0_TCR) = 0x1;			// Counter0 is enabled
}

void lpc2106_vectored_interrupts_init(unsigned long timer0_irq_handler,
						unsigned long uart0_irq_handler,
						unsigned long default_irq_handler)
{
	REG32(VICIntSelect) = 0x0;	// All interrupts are assigned to IRQ category
	REG32(VICIntEnable) = 0x50;	// Timer0 (bit4) uart0 (bit6) interrupt is enabled  /1010000/
	REG32(VICVectAddr0) = timer0_irq_handler;	// Timer0 IRQ handler
	REG32(VICVectCntl0) = 0x24; // interrupt source is timer0 (source 4) and enable (bit 5) /1 00100/
	REG32(VICVectAddr1) = uart0_irq_handler;     // UART0 IRQ handler
	REG32(VICVectCntl1) = 0x26;  // interrupt source is uart0 (source 6) and enable (bit 5) /1 00110/
	REG32(VICDefVectAddr) = default_irq_handler;
}

void lpc2106_run(void)
{
	lpc2106_MAM_init();
	lpc2106_PLL_init();
	lpc2106_ports_init();
	lpc2106_timer_init();
	lpc2106_serial_init();
}

==> TaltOSv0.1.3.zip: TaltOSv0.1.3/bootloader/lpc2106_init.c <==
/************************************************************************
* This functions are used for initializing LPC2106 chip on an eval board*
************************************************************************/
#include "lpc2106_memorymap.h"
#include "lpc2106_init.h"

void lpc2106_MAM_init(void);

void lpc2106_PLL_init(void);

void lpc2106_ports_init(void);

void lpc2106_serial_init(void);

void lpc2106_timer_init(void);

void lpc2106_MAM_init(void)
{
	REG8(SYSCON_MAMCR) 	= 0x00;		// MAM functions disabled
	REG8(SYSCON_MAMTIM)	= 0x03;		// MAM fech time 1 processor clock
	REG8(SYSCON_MAMCR) 	= 0x02;		// MAM functions fully enabled
}

void lpc2106_PLL_init(void)
{
	REG32(VICIntEnClr) = 0xFFFFFFFF;	// Disabling IT
	// Set up the PLL frequency
	REG8(SYSCON_PLLCFG) = 0x25;		// P = 2, M = 6
	REG8(SYSCON_PLLCON) = 0x01;		// Enabling PLL but not connecting it

	REG8(SYSCON_PLLFEED) = 0xAA;	// Actualising the setting
	REG8(SYSCON_PLLFEED) = 0x55;	// Actualising the setting

	while ( !(REG16(SYSCON_PLLSTAT) & 0x0400) );	// waiting for PLL lock

	REG8(SYSCON_PLLCON) =  0x03;	// Enabling PLL but not connecting it

	REG8(SYSCON_PLLFEED) = 0xAA;	// Actualising the setting
	REG8(SYSCON_PLLFEED) = 0x55;	// Actualising the setting
}

void lpc2106_ports_init(void)
{
	REG32(PCB_PINSEL0) = 0x00000005;	// USART TX / RX
}

void lpc2106_serial_init(void)
{
	REG8(UART0_LCR) = 0x83;		// * bit character 1 stop bit no parity Enable Divisor Latches
	REG8(UART0_DLL) = 98;		// 9600 Baud
	REG8(UART0_DLM) = 0;
	REG8(UART0_LCR) = 0x03;		// * bit character 1 stop bit no parity Disable Divisor Latches
	REG8(UART0_FCR) = 0x41;		// * Enabling and clearing Rx Tx FIFOs and settin Rx trigger to 01 (4 byte)
	REG8(UART0_IER) = 0x03;		// Enabling RDA and THRE interrupts for uart0 bit 0 and bit 1
}

void lpc2106_timer_init(void)
{
	REG8(SYSCON_VPBDIV) = 0x00;	// Divide system clock by four for the peripherals 60Mhz/4 = 15Mhz

	REG16(TIMER0_MCR) = 0x3;		// Interrupt and reset on match with MR0
	REG32(TIMER0_PR)  = 100;		// 15Mhz/100 = 0.15Mhz
	REG32(TIMER0_MR0) = 750;		// 0.15Mhz/750 = 200Hz

	REG8(TIMER0_TCR) = 0x1;			// Counter0 is enabled
}

void lpc2106_vectored_interrupts_init(unsigned long timer0_irq_handler,
						unsigned long uart0_irq_handler,
						unsigned long default_irq_handler)
{
	REG32(VICIntSelect) = 0x0;	// All interrupts are assigned to IRQ category
	REG32(VICIntEnable) = 0x50;	// Timer0 (bit4) uart0 (bit6) interrupt is enabled  /1010000/
	REG32(VICVectAddr0) = timer0_irq_handler;	// Timer0 IRQ handler
	REG32(VICVectCntl0) = 0x24; // interrupt source is timer0 (source 4) and enable (bit 5) /1 00100/
	REG32(VICVectAddr1) = uart0_irq_handler;     // UART0 IRQ handler
	REG32(VICVectCntl1) = 0x26;  // interrupt source is uart0 (source 6) and enable (bit 5) /1 00110/
	REG32(VICDefVectAddr) = default_irq_handler;
}

void lpc2106_run(void)
{
	lpc2106_MAM_init();
	lpc2106_PLL_init();
	lpc2106_ports_init();
	lpc2106_timer_init();
	lpc2106_serial_init();
}
